@@ -1,5 +1,7 @@
 from .agents import CreateAgent, DropAgent, UpdateAgent
+from .alter_database import AlterDatabase
 from .create_view import CreateView
+from .alter_view import AlterView
 from .create_database import CreateDatabase
 from .create_predictor import CreatePredictor, CreateAnomalyDetectionModel
 from .drop_predictor import DropPredictor
@@ -15,7 +17,8 @@ from .create_job import CreateJob
 from .drop_job import DropJob
 from .chatbot import CreateChatBot, UpdateChatBot, DropChatBot
 from .trigger import CreateTrigger, DropTrigger
-from .knowledge_base import CreateKnowledgeBase, DropKnowledgeBase
+from .knowledge_base import CreateKnowledgeBase, DropKnowledgeBase, CreateKnowledgeBaseIndex, DropKnowledgeBaseIndex \
+    , EvaluateKnowledgeBase
 from .skills import CreateSkill, DropSkill, UpdateSkill
 
 # remove it in next release
