@@ -46,10 +46,11 @@ class MindsDBParser(Parser):
         ('left', OR),
         ('left', AND),
         ('right', UNOT),
-        ('left', EQUALS, NEQUALS),
-        ('nonassoc', LESS, LEQ, GREATER, GEQ, IN, NOT_IN, BETWEEN, IS, IS_NOT, NOT_LIKE, LIKE),
+        ('left', EQUALS, NEQUALS, ASSIGN_COLON),
+        ('nonassoc', LESS, LEQ, GREATER, GEQ, IN, NOT_IN, BETWEEN, IS, IS_NOT, NOT_LIKE, LIKE, RIGHT_SHIFT, LEFT_SHIFT),
         ('left', JSON_GET),
         ('left', PLUS, MINUS),
+        ('left', BIT_AND, BIT_XOR, BIT_OR),
         ('left', STAR, DIVIDE, TYPECAST, MODULO),
         ('right', UMINUS),  # Unary minus operator, unary not
 
@@ -198,6 +199,7 @@ class MindsDBParser(Parser):
         return DropAgent(name=p.identifier, if_exists=p.if_exists_or_empty)
     
     @_('UPDATE AGENT identifier SET kw_parameter_list')
+    @_('ALTER AGENT identifier USING kw_parameter_list')
     def update_agent(self, p):
         return UpdateAgent(name=p.identifier, updated_params=p.kw_parameter_list)
 
@@ -536,7 +538,7 @@ class MindsDBParser(Parser):
         value0 = command.from_table
         value1 = p.identifier
         if value0 is not None:
-            value1.parts = value1.parts + value0.parts
+            value1.append(value0)
 
         command.from_table = value1
         return command
@@ -547,7 +549,7 @@ class MindsDBParser(Parser):
         value0 = command.in_table
         value1 = p.identifier
         if value0 is not None:
-            value1.parts = value1.parts + value0.parts
+            value1.append(value0)
 
         command.in_table = value1
         return command
@@ -1631,8 +1633,14 @@ class MindsDBParser(Parser):
        'expr STAR expr',
        'expr DIVIDE expr',
        'expr MODULO expr',
+       'expr BIT_AND expr',
+       'expr BIT_XOR expr',
+       'expr BIT_OR expr',
+       'expr ASSIGN_COLON expr',
        'expr EQUALS expr',
        'expr NEQUALS expr',
+       'expr RIGHT_SHIFT expr',
+       'expr LEFT_SHIFT expr',
        'expr GEQ expr',
        'expr GREATER expr',
        'expr GEQ LAST',
@@ -1657,10 +1665,20 @@ class MindsDBParser(Parser):
        'expr NOT_IN expr',
        'expr IN expr',)
     def expr(self, p):
+        if p[1] == ':=':
+            # allow 'assign' only for variables
+            if not isinstance(p[0], Variable):
+                raise ParsingException("Assignment `:=` allowed only to variables (@var := ...)")
         if hasattr(p, 'LAST'):
             arg1 = Last()
         else:
             arg1 = p[2]
+
+        op = p[1]
+        if op.lower() in ("in", "not in") and isinstance(arg1, Constant) and arg1.parentheses:
+            arg1.parentheses = False
+            arg1 = Tuple([arg1])
+
         return BinaryOperation(op=p[1], args=(p[0], arg1))
 
     @_('MINUS expr %prec UMINUS',
@@ -1812,17 +1830,21 @@ class MindsDBParser(Parser):
        'identifier DOT star')
     def identifier(self, p):
         node = p[0]
-        is_quoted = False
         if isinstance(p[2], Star):
             node.parts.append(p[2])
+            node.is_quoted.append(False)
         elif isinstance(p[2], int):
             node.parts.append(str(p[2]))
+            node.is_quoted.append(False)
         elif isinstance(p[2], str):
             node.parts.append(p[2])
+            node.is_quoted.append(False)
+        elif isinstance(p[2], Identifier):
+            node.append(p[2])
         else:
-            node.parts += p[2].parts
-            is_quoted = p[2].is_quoted[0]
-        node.is_quoted.append(is_quoted)
+            # fallback, shouldn't happen
+            node.parts.append(str(p[2]))
+            node.is_quoted.append(False)
         return node
 
     @_('quote_string',
@@ -2072,3 +2094,10 @@ class MindsDBParser(Parser):
         )
         # don't raise exception
         return
+
+    @_('TABLE identifier')
+    def select(self, p):
+        return Select(
+            targets=[Star()],
+            from_table=p.identifier,
+        )
